@@ -44,7 +44,7 @@ option_version_cb (const gchar *option_name,
 	exit (0);
 }
  
-const GOptionEntry options[] = {
+const GOptionEntry all_options[] = {
 	{"debug", '\0', 0, G_OPTION_ARG_NONE, &optionstate.debug, N_("Enable debug"), NULL},
 	{"play-pause", '\0', 0, G_OPTION_ARG_NONE, &optionstate.playpause, N_("Play/Pause"), NULL},
 	{"play", '\0', 0, G_OPTION_ARG_NONE, &optionstate.play, N_("Play"), NULL},
@@ -70,7 +70,7 @@ const GOptionEntry options[] = {
 };
 
 void
-totem_options_process_late (Totem *totem, const TotemCmdLineOptions* options)
+totem_options_process_late (Totem *totem, const TotemCmdLineOptions *options)
 {
 	if (options->togglecontrols) 
 		totem_action_toggle_controls (totem);
@@ -82,6 +82,21 @@ totem_options_process_late (Totem *totem, const TotemCmdLineOptions* options)
 	totem->seek_to = options->seek;
 }
 
+void
+totem_options_register_remote_commands (Totem *totem)
+{
+	GEnumClass *klass;
+	guint i;
+
+	klass = (GEnumClass *) g_type_class_ref (TOTEM_TYPE_REMOTE_COMMAND);
+	for (i = TOTEM_REMOTE_COMMAND_UNKNOWN + 1; i < klass->n_values; i++) {
+		GEnumValue *val;
+		val = g_enum_get_value (klass, i);
+		unique_app_add_command (totem->app, val->value_name, i);
+	}
+	g_type_class_unref (klass);
+}
+
 void
 totem_options_process_early (Totem *totem, const TotemCmdLineOptions* options)
 {
